@@ -4,7 +4,7 @@ c     ==================
 
       implicit double precision (a-h,o-z)
       character*12 fname
-      common /comrp/ coeff(3)
+      common /cparam/ coeff(3)
 c
 c     # for 3d Burgers' equation
 c     #    q_t  +  u*(.5*q^2)_x + v*(.5*q^2)_y + w*(.5*q^2)_z = 0
