@@ -2,21 +2,18 @@ c
 c --------------------------------------------------------------
 c
       subroutine preicall(val,aux,nrow,ncol,nvar,naux,
-     1                    ilo,ihi,jlo,jhi,level,locflip)
+     1                    ilo,ihi,jlo,jhi,level,fliparray)
 c
       use amr_module
       implicit double precision (a-h,o-z)
 
-
+      dimension fliparray((nrow+ncol)*nghost*(nvar+naux))
       dimension val(nvar,nrow,ncol)
       dimension aux(naux,nrow,ncol)
 
       dimension ist(3), iend(3), jst(3), jend(3), ishift(3), jshift(3)
+      logical   xint, yint
 c
-c OLD INDEXING
-c      iadd   (i,j,ivar)  = locflip    + i - 1 + nr*((ivar-1)*nc+j-1)
-c      iaddaux(i,j,iaux)  = locflipaux + i - 1 + nr*((iaux-1)*nc+j-1)
-
 c NEW INDEXING - ORDER SWITCHED
       iadd   (ivar,i,j)  = locflip    + ivar-1 + nvar*((j-1)*nc+i-1)
       iaddaux(iaux,i,j)  = locflipaux + iaux-1 + naux*((j-1)*nc+i-1)
@@ -37,43 +34,76 @@ c     The values of the grid are inserted
 c     directly into the enlarged val array for this piece.
 c
 c :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
-
 c
-c     # will divide patch into 9 possibilities (some empty):
-c       x sticks out left, x interior, x sticks out right
-c       same for y. for example, the max. would be
-c       i from (ilo,-1), (0,iregsz(level)-1), (iregsz(level),ihi)
+!     ## fliparray now passed in; index into it below
+        locflip = 1
+        locflipaux = 1 + nvar*(ncol+nrow)
+c
+c     ## will divide patch into 9 possibilities (some empty):
+c     ## x sticks out left, x interior, x sticks out right
+c     ## same for y. for example, the max. would be
+c     ## i from (ilo,-1), (0,iregsz(level)-1), (iregsz(level),ihi)
 
-        ist(1) = ilo
-        ist(2) = 0
-        ist(3) = iregsz(level)
-        iend(1) = -1
-        iend(2) = iregsz(level)-1
-        iend(3) = ihi
+        if (xperdom) then
+           ist(1)    = ilo
+           ist(2)    = 0
+           ist(3)    = iregsz(level)
+           iend(1)   = -1
+           iend(2)   = iregsz(level)-1
+           iend(3)   = ihi
+           ishift(1) = iregsz(level)
+           ishift(2) = 0
+           ishift(3) = -iregsz(level)
+        else   ! if not periodic, set vals to only have nonnull intersection for interior regoin
+           ist(1)    = iregsz(level)
+           ist(2)    = ilo
+           ist(3)    = iregsz(level)
+           iend(1)   = -nghost
+           iend(2)   = ihi
+           iend(3)   = -nghost
+           ishift(1) = 0
+           ishift(2) = 0
+           ishift(3) = 0
+        endif
 
-        jst(1) = jlo
-        jst(2) = 0
-        jst(3) = jregsz(level)
-        jend(1) = -1
-        jend(2) = jregsz(level)-1
-        jend(3) = jhi
 
-        ishift(1) = iregsz(level)
-        ishift(2) = 0
-        ishift(3) = -iregsz(level)
-        jshift(1) = jregsz(level)
-        jshift(2) = 0
-        jshift(3) = -jregsz(level)
+        if (yperdom .or. spheredom) then
+           jst(1)    = jlo
+           jst(2)    = 0
+           jst(3)    = jregsz(level)
+           jend(1)   = -1
+           jend(2)   = jregsz(level)-1
+           jend(3)   = jhi
+           jshift(1) = jregsz(level)
+           jshift(2) = 0
+           jshift(3) = -jregsz(level)
+        else
+           jst(1)    = jregsz(level)
+           jst(2)    = jlo
+           jst(3)    = jregsz(level)
+           jend(1)   = -nghost
+           jend(2)   = jhi
+           jend(3)   = -nghost
+           jshift(1) = 0
+           jshift(2) = 0
+           jshift(3) = 0
+        endif
 
+c      ## loop over the 9 regions (in 2D) of the patch - the interior is i=j=2 plus
+c      ## the ghost cell regions.  If any parts stick out of domain and are periodic
+c      ## map indices periodically, but stick the values in the correct place
+c      ## in the orig grid (indicated by iputst,jputst.
+c      ## if a region sticks out of domain  but is not periodic, not handled in (pre)-icall 
+c      ## but in setaux/bcamr (not called from here).
        do 20 i = 1, 3
           i1 = max(ilo,  ist(i))
           i2 = min(ihi, iend(i))
+          if (i1 .gt. i2) go to 20 ! non-empty intersection not possible
        do 10 j = 1, 3
           j1 = max(jlo,  jst(j))
           j2 = min(jhi, jend(j))
-
-
-          if ((i1 .le. i2) .and. (j1 .le. j2)) then ! part of patch in this region
+ 
+          if (j1 .le. j2) then ! part of patch in this region
 c
 c check if special mapping needed for spherical bc. 
 c (j=2 is interior,nothing special needed)
@@ -109,19 +139,21 @@ c             swap so that smaller one is left index, etc since mapping reflects
               ybwrap = ylower + jwrap1*hyposs(level)
               jwrap2 = j2 + jbump
 
-c   ## scratch space now passed in through locflip for both soln and aux
-c             locflip = igetsp(nr*nc*(nvar+naux))
-              locflipaux = locflip + nr*nc*nvar
-              if (naux>0) call setaux(ng,nr,nc,xlwrap,ybwrap,
+              if (naux>0) then
+                 fliparray(locflip:locflip+ naux*(ncol+nrow)-1) = 
+     1                     NEEDS_TO_BE_SET
+                 call setaux(ng,nr,nc,xlwrap,ybwrap,
      1                    hxposs(level),hyposs(level),naux,
-     2                    alloc(locflipaux))
+     2                    fliparray(locflipaux))
+              endif 
 
 c             write(dbugunit,101) i1,i2,j1,j2
 c             write(dbugunit6,102) iwrap1,iwrap2,j1+jbump,j2+jbump
  101          format(" actual patch from i:",2i5," j :",2i5)
  102          format(" icall called w i:",2i5," j :",2i5)
-              call icall(alloc(locflip),alloc(locflipaux),nr,nc,nvar,
-     1                   naux,iwrap1,iwrap2,jwrap1,jwrap2,level,1,1)
+              call icall(fliparray(locflip),fliparray(locflipaux),
+     1                   nr,nc,nvar, naux,iwrap1,iwrap2,jwrap1,jwrap2,
+     2                   level,1,1)
 
 c             copy back using weird mapping for spherical folding
               nrowst = 1   ! start filling up val at (1,1) - no additional offset
@@ -134,18 +166,15 @@ c    1                            nc-jj+j1
 
                 do 17 ivar = 1, nvar
                    val(ivar,nrowst+(ii-ilo),ncolst+(jj-jlo)) = 
-     1                    alloc(iadd(ivar,nr-(ii-i1),nc-(jj-j1)))
+     1                    fliparray(iadd(ivar,nr-(ii-i1),nc-(jj-j1)))
  17             continue
 
                 do 16 iaux = 1, naux
                    aux(iaux,nrowst+(ii-ilo),ncolst+(jj-jlo)) = 
-     1                    alloc(iaddaux(iaux,nr-(ii-i1),nc-(jj-j1)))
+     1                    fliparray(iaddaux(iaux,nr-(ii-i1),nc-(jj-j1)))
  16             continue
  15           continue
              
-c  ## scratch space now done above, in case dynamic memory moves alloc
-c             call reclam(locflip, (nr*nc*(nvar+naux)))
-
             endif
 
           endif
