@@ -122,6 +122,13 @@ class Grid(object):
         self.compute_c_centers(self)
         return self._c_centers
     _c_centers = None
+    def c_centers_with_ghost(self,num_ghost):
+        r"""(list of ndarray(...)) - List containing the arrays locating
+                the computational locations of cell centers, see 
+                :meth:`compute_c_centers` for more info."""
+        self.compute_c_centers_with_ghost(num_ghost)
+        return self._c_centers_with_ghost
+    _c_centers_with_ghost = None
     @property
     def c_edges(self):
         r"""(list of ndarray(...)) - List containing the arrays locating
@@ -130,7 +137,13 @@ class Grid(object):
         self.compute_c_edges(self)
         return self._c_edges
     _c_edges = None
-
+    def c_edges_with_ghost(self,num_ghost):
+        r"""(list of ndarray(...)) - List containing the arrays locating
+                  the computational locations of cell edges, see 
+                  :meth:`compute_c_edges` for more info."""
+        self.compute_c_edges_with_ghost(num_ghost)
+        return self._c_edges_with_ghost
+    _c_edges_with_ghost = None
        
     
     # ========== Class Methods ===============================================
@@ -157,6 +170,8 @@ class Grid(object):
         `Controller` class is used to run the application, this directory by
         default will be created under the `Controller` `outdir` directory.
         """
+        self.num_ghost = None
+
         # Dimension parsing
         if isinstance(dimensions,Dimension):
             dimensions = [dimensions]
@@ -302,35 +317,38 @@ class Grid(object):
                     #numpy arrays instead of lists of numpy arrays
                     self._c_centers.append(center_array[index[i,...]])
 
-    def compute_c_centers_with_ghost(self, nghost, recompute=False):
+    def compute_c_centers_with_ghost(self, num_ghost,recompute=False):
         r"""
-        Calculate the :attr:`c_centers` array
+        Calculate the :attr:`c_centers_with_ghost` array
         
         This array is computed only when requested and then stored for later
         use unless the recompute flag is set to True.
         
         Access the resulting computational coodinate array via the
         corresponding dimensions or via the computational grid properties
-        :attr:`c_centers`.
+        :attr:`c_centers_with_ghost`.
         
         :Input:
          - *recompute* - (bool) Whether to force a recompute of the arrays
         """
-        setattr(self, _nghost, nghost)
-
-        if recompute or (self._c_centers is None):
-            self._c_centers = [None]*self.num_dim
+        if recompute or (self._c_centers_with_ghost is None):
+            self._c_centers_with_ghost = [None]*self.num_dim
             
+            for i in xrange(0,self.num_dim):
+                self.dimensions[i]._centers_with_ghost = None
+                self.dimensions[i]._c_centers_with_ghost = None
+                self.dimensions[i].num_ghost = num_ghost
+
             # For one dimension, the center and edge arrays are equivalent
             if self.num_dim == 1:
-                self._c_centers[0] = self.dimensions[0].centers
+                self._c_centers_with_ghost[0] = self.dimensions[0].centers_with_ghost
             else:
-                index = np.indices(self.num_cells)
-                self._c_centers = []
+                index = np.indices(n+2*num_ghost for n in self.num_cells)
+                self._c_centers_with_ghost = []
                 for i,center_array in enumerate(self.get_dim_attribute('centers_with_ghost')):
                     #We could just use indices directly and deal with
                     #numpy arrays instead of lists of numpy arrays
-                    self._c_centers.append(center_array[index[i,...]])
+                    self._c_centers_with_ghost.append(center_array[index[i,...]])
 
     def compute_c_edges(self, recompute=False):
         r"""
@@ -346,19 +364,50 @@ class Grid(object):
         :Input:
          - *recompute* - (bool) Whether to force a recompute of the arrays
         """
-        if recompute or not len(self._c_edges) == len(self._dimensions):
-            self._c_edges = [None for i in xrange(self.num_dim)]
-            
+        if recompute or (self._c_edges is None):
+            self._c_edges = [None]*self.num_dim
+
             if self.num_dim == 1:
                 self._c_edges[0] = self.dimensions[0].edges
             else:
-                index = np.indices([n+1 for n in self.num_cells])
+                index = np.indices(n+1 for n in self.num_cells)
                 self._c_edges = []
                 for i,edge_array in enumerate(self.get_dim_attribute('edges')):
                     #We could just use indices directly and deal with
                     #numpy arrays instead of lists of numpy arrays
                     self._c_edges.append(edge_array[index[i,...]])
             
+    def compute_c_edges_with_ghost(self, num_ghost,recompute=False):
+        r"""
+        Calculate the :attr:`c_centers_with_ghost` array
+        
+        This array is computed only when requested and then stored for later
+        use unless the recompute flag is set to True.
+        
+        Access the resulting computational coodinate array via the
+        corresponding dimensions or via the computational grid properties
+        :attr:`c_centers_with_ghost`.
+        
+        :Input:
+         - *recompute* - (bool) Whether to force a recompute of the arrays
+        """
+        if recompute or (self._c_edges_with_ghost is None):
+            self._c_edges_with_ghost = [None]*self.num_dim
+
+            # For one dimension, the center and edge arrays are equivalent
+            for i in xrange(0,self.num_dim):
+                self.dimensions[i]._edges_with_ghost = None
+                self.dimensions[i].num_ghost = num_ghost
+
+            if self.num_dim == 1:
+                self._c_edges_with_ghost[0] = self.dimensions[0].edges_with_ghost
+            else:
+                index = np.indices(n+2*num_ghost+1 for n in self.num_cells)
+                self._c_edges_with_ghost = []
+                for i,center_array in enumerate(self.get_dim_attribute('edges_with_ghost')):
+                    #We could just use indices directly and dneal with
+                    #numpy arrays instead of lists of numpy arrays
+                    self._c_edges_with_ghost.append(center_array[index[i,...]])
 
     # ========================================================================
     #  Gauges
@@ -475,23 +524,23 @@ class Dimension(object):
         r"""(ndarrary(:)) - Location of all cell center coordinates
         for this dimension, including centers of ghost cells."""
         centers = self.centers
-        nghost  = self._nghost
+        num_ghost  = self.num_ghost
         if self._centers_with_ghost is None:
-            pre  = np.linspace(self.lower-(nghost-0.5)*self.delta,self.lower-0.5*self.delta,nghost)
-            post = np.linspace(self.upper+0.5*self.delta, self.upper+(nghost-0.5)*self.delta,nghost)
-            self._centers_with_ghost = np.hstack((pr,centers,post))
-        return self._centers_with_ghost #np.hstack((pre,centers,post))
+            pre = self.lower+(np.arange(-num_ghost,0)+0.5)*self.delta
+            post = self.upper + self.delta * (np.arange(num_ghost) + 0.5)
+            self._centers_with_ghost = np.hstack((pre,centers,post))
+        return self._centers_with_ghost
     _centers_with_ghost = None
     @property
     def edges_with_ghost(self):
         edges   = self.edges
-        nghost  = self._nghost
+        num_ghost  = self.num_ghost
         if self._edges_with_ghost is None:
-            pre  = np.linspace(self.lower-(nghost)*self.delta,self.lower-self.delta,nghost)
-            post = np.linspace(self.upper+self.delta, self.upper+(nghost)*self.delta,nghost)
-            self._edges_with_ghost = np.hstack((pr,edges,post))
+            pre  = np.linspace(self.lower-(num_ghost)*self.delta,self.lower-self.delta,num_ghost)
+            post = np.linspace(self.upper+self.delta, self.upper+(num_ghost)*self.delta,num_ghost)
+            self._edges_with_ghost = np.hstack((pre,edges,post))
         return self._edges_with_ghost
-
+    _edges_with_ghost = None
     
     def __init__(self, *args, **kargs):
         r"""
@@ -516,7 +565,8 @@ class Dimension(object):
         self.units = None
         r"""(string) Corresponding physical units of this dimension (e.g. 
         'm/s'), ``default = None``"""
-        
+        self.num_ghost = None
+
         # Parse args
         if isinstance(args[0],float):
             self.lower = float(args[0])
