@@ -5,11 +5,23 @@ Pyclaw utility methods
 """
 
 import time
-import os,sys
+import os
+import sys
 import subprocess
 import logging
 import tempfile
+import inspect
+import warnings
+
 import numpy as np
+import contextlib
+
+
+LOGGING_LEVELS = {0:logging.CRITICAL,
+                  1:logging.ERROR,
+                  2:logging.WARNING,
+                  3:logging.INFO,
+                  4:logging.DEBUG}
 
 def add_parent_doc(parent):
     """add parent documentation for a class""" 
@@ -19,6 +31,55 @@ def add_parent_doc(parent):
     ==========================
     """ + parent.__doc__
 
+def run_serialized(fun):
+    """ Decorates a function to only run serially, even if called in parallel.
+
+    In a parallel communicator, the first process will run while the remaining processes
+    block on a barrier.  In a serial run, the function will be called directly.
+
+    This currently assumes the global communicator is PETSc.COMM_WORLD, but is easily
+    generalized.
+    """
+
+    try:
+        from petsc4py import PETSc
+        is_parallel = True
+    except ImportError:
+        is_parallel = False
+
+    if is_parallel:
+        rank = PETSc.COMM_WORLD.getRank()
+        if rank == 0:
+            def serial_fun(*args, **kwargs):
+                fun(*args, **kwargs)
+                PETSc.COMM_WORLD.Barrier()
+        else:
+            def serial_fun(*args, **kwargs):
+                PETSc.COMM_WORLD.Barrier()
+    else:
+        def serial_fun(*args, **kwargs):
+            fun(*args, **kwargs)
+
+    return serial_fun
+
+@run_serialized
+def inplace_build(working_dir, warn=True):
+    """Build missing extension modules with an in-place build.  This is a convenience
+    function for PyClaw applications that rely on custom extension modules.  In its default
+    mode, this function emits warnings indicating its actions.
+
+    This function is safe to execute in parallel, it will only run on the 0 zero process while
+    the other processes block.
+    """
+
+    if warn:
+        warnings.warn("missing extension modules")
+        warnings.warn("running python setup.py build_ext -i in %s" % working_dir)
+
+    subprocess.check_call('python setup.py build_ext -i', shell=True, cwd=working_dir)
+
+    if warn:
+        warnings.warn("successfully executed python setup.py build_ext -i in %s" % working_dir)
 
 def run_app_from_main(application,setplot=None):
     r"""
@@ -44,8 +105,15 @@ def run_app_from_main(application,setplot=None):
     else:
         from clawpack import pyclaw
 
-    app_kwargs = {key: value for key, value in pyclaw_kwargs.items() 
-                  if not key in ('htmlplot','iplot')}
+    if sys.version_info >= (2, 7):
+        app_kwargs = {key: value for key, value in pyclaw_kwargs.items() 
+                      if not key in ('htmlplot','iplot')}
+    else:
+        # the above fails with Python < 2.7, so write it out...
+        app_kwargs = {}
+        for key,value in pyclaw_kwargs.items():
+            if key not in ('htmlplot','iplot'):
+                app_kwargs[key] = value
 
     claw=application(**app_kwargs)
 
@@ -93,17 +161,27 @@ def gen_variants(application, verifier, kernel_languages=('Fortran',), **kwargs)
 
     for test_kwargs in arg_dicts:
         test_kwargs.update(kwargs)
-        yield (test_app, application, verifier, test_kwargs)
+        try:
+            test_name = application.__module__
+        except:
+            test_name = inspect.getmodule(application)
+        if 'solver_type' in test_kwargs:
+            solver_info = 'solver_type={solver_type!s}, '
+        else:
+            solver_info = ''
+        test = lambda: test_app(application, verifier, test_kwargs)
+        test.description = '%s(%s)' % (test_name, str(kwargs))
+        yield test
     return
 
 def build_variant_arg_dicts(kernel_languages=('Fortran',)):
     import itertools
 
-    # only test petsc4py if it is available
+    # test petsc4py only if it is available
     try:
         import petsc4py
         use_petsc_opts=(True,False)
-    except Exception as err:
+    except ImportError:
         use_petsc_opts = (False,)
 
     opt_names = 'use_petsc','kernel_language'
@@ -158,7 +236,6 @@ def test_app(application, verifier, kwargs):
     check_values = verifier(claw)
 
     if check_values is not None:
-        import inspect
         err = \
         """%s
 ********************************************************************************
@@ -434,7 +511,7 @@ def construct_function_handle(path,function_name=None):
 
 
 #---------------------------------------------------------
-def read_data_line(inputfile,num_entries=1,type='float'):
+def read_data_line(inputfile,num_entries=1,data_type=float):
 #---------------------------------------------------------
     r"""
     Read data a single line from an input file
@@ -443,7 +520,7 @@ def read_data_line(inputfile,num_entries=1,type='float'):
 
     inputfile: a file pointer to an open file object
     num_entries: number of entries that should be read, defaults to only 1
-    type: Type of the values to be read in, they all most be the same type
+    type: Type of the values to be read in, they all must be the same type
 
     This function will return either a single value or an array of values
     depending on if num_entries > 1
@@ -453,22 +530,14 @@ def read_data_line(inputfile,num_entries=1,type='float'):
     while  l==[]:  # skip over blank lines
         line = inputfile.readline()
         l = line.split()
-    val = np.empty(num_entries,type)
+    val = np.empty(num_entries,data_type)
     if num_entries > len(l):
         print 'Error in read_data_line: num_entries = ', num_entries
         print '  is larger than length of l = ',l
-    try:
-        for i in range(num_entries):
-            exec("val[i] = %s(l[i])" % type)
-        if num_entries == 1:  # This is a convenience for calling functions
-            return val[0]
-        return val
-    except(ValueError):
-        print "Invalid type for the %s value in %s" % (i,l)
-        print "  type = ",type
-        return None
-    except:
-        raise
+    if num_entries == 1:  # This is a convenience for calling functions
+        return data_type(l[0])
+    val = [data_type(entry) for entry in l[:num_entries]]
+    return val
 
 #----------------------------------------
 def convert_fort_double_to_float(number):
