@@ -90,7 +90,12 @@ class ClawPlotData(clawdata.ClawData):
                                         # in each frame are done
 
         self.add_attribute('plotfigure_dict',{})  
-        self.add_attribute('otherfigure_dict',{})  
+        try:
+            from collections import OrderedDict   # new in Python 2.7
+            d = OrderedDict()  
+        except:
+            d = {}
+        self.add_attribute('otherfigure_dict',d)  
 
         self.add_attribute('framesoln_dict',{})        # dictionary for holding framesoln
                                         # objects associated with plots
@@ -294,7 +299,7 @@ class ClawPlotData(clawdata.ClawData):
 
                 # Check to make sure the gauge requested is in the data file
                 if gaugeno not in gauge_data.gauge_numbers:
-                    raise Exception("Could not find guage %s in gauges data file.")
+                    raise Exception("Could not find gauge %s in gauges.data file.")
             
                 # Extract locations from gauge data file to be used with the
                 # solutions below
@@ -303,7 +308,9 @@ class ClawPlotData(clawdata.ClawData):
                     locations[gauge[0]] = gauge[1:3]
 
             except:
-                print "*** WARNING *** Could not read gauges data file."
+                print "*** WARNING *** Could not read gauges.data file from"
+                print "     %s" % outdir
+                print "*** Unable to determine gauge locations"
                 # raise Warning()
 
             # Read in all gauges
@@ -317,10 +324,27 @@ class ClawPlotData(clawdata.ClawData):
                     raw_data = np.loadtxt(file_path)
 
                     gauge_read_string = ""
-                    raw_numbers = np.array(raw_data[:,0], dtype=int)    # Convert type for equality comparison
-                    for n in gauge_data.gauge_numbers:
+
+                    if len(raw_data) == 0:
+                        print '*** Warning: fort.gauge is empty'
+                        gauge_numbers = []
+                    else:
+                        # Convert type for equality comparison:
+                        raw_numbers = np.array(raw_data[:,0], dtype=int)    
+                        
+                        gauge_numbers = list(set(raw_numbers))
+                        gauge_numbers.sort()
+                        print "In fort.gauge file, found gauge numbers %s" \
+                          % gauge_numbers
+
+
+                    for n in gauge_numbers:
+                        try:
+                            loc = locations[n]
+                        except:
+                            loc = None
                         gauge = gaugetools.GaugeSolution(gaugeno, 
-                                                         location=locations[n])
+                                                         location=loc)
                         gauge_indices = np.nonzero(n == raw_numbers)[0]
 
                         gauge.level = [int(value) for value in raw_data[gauge_indices,1]]
@@ -336,6 +360,7 @@ class ClawPlotData(clawdata.ClawData):
             except Exception as e:
                 print '*** Error reading gauges in ClawPlotData.getgauge'
                 print '*** outdir = ', outdir
+                import pdb; pdb.set_trace()
                 raise e
 
         # Attempt to fetch gauge requested
@@ -533,6 +558,7 @@ class ClawPlotData(clawdata.ClawData):
         self._otherfignames.append(name)
         otherfigure = ClawOtherFigure(name,self)
         self.otherfigure_dict[name] = otherfigure
+        otherfigure.fname = fname
         return otherfigure
 
     def set_outdirs(self):
